<?php

//Bu dosya doğrudan çağrılırsa iptal edin.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Çekirdek eklenti sınıfını tanımlayan dosya
 *
 * Her ikisinde de kullanılan öznitelikleri ve işlevleri içeren bir sınıf tanımı
 * sitenin ve yönetici alanının herkese açık tarafı.
 *
 * @since      1.0.0
 *
 * @package    Entego_N11
 * @subpackage Entego_N11/includes
 */

/**
 * Çekirdek eklenti sınıfı.
 *
 * Bu, uluslararasılaştırmayı, yöneticiye özgü kancaları ve
 * halka açık site kancaları.
 *
 * Ayrıca bu eklentinin benzersiz tanımlayıcısını ve akımını korur
 * eklentinin sürümü.
 *
 * @since      1.0.0
 * @package    Entego_N11
 * @subpackage Entego_N11/includes
 */
class Entego_N11 {

	/**
	 * Gücü oluşturan tüm kancaları korumak ve kaydetmekle yüklenen yükleyici
	 * eklenti.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Entego_N11_Loader    $loader    Eklenti için tüm kancaları tutar ve kaydeder.
	 */
	protected $loader;

	/**
	 * Bu eklentinin benzersiz tanımlayıcısı.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $entego_n11    Bu eklentiyi benzersiz bir şekilde tanımlamak için kullanılan dize.
	 */
	protected $entego_n11;

	/**
	 * The single instance of the class.
	 *
	 */
	protected static $_instance = null;

	/**
	 * Eklentinin geçerli sürümü.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    Eklentinin geçerli sürümü.
	 */
	protected $version;

	/**
	 * Eklentinin temel işlevlerini tanımlayın.
	 *
	 * Eklenti adını ve eklenti boyunca kullanılabilecek eklenti sürümünü ayarlayın.
	 * Bağımlılıkları yükleyin, yerel ayarı tanımlayın ve yönetici alanı için kancaları ayarlayın ve
	 * sitenin halka bakan tarafı.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {
		if ( defined( 'ENTEGO_N11_VERSION' ) ) {
			$this->version = ENTEGO_N11_VERSION;
		} else {
			$this->version = '1.0.0';
		}
		$this->entego_n11 = 'entego_n11';

		$this->load_dependencies();
		$this->define_admin_hooks();
		add_action( 'admin_menu', array($this,'menu_ekle') );
		add_action( 'init', array($this,'includes') );

	}

	/**
	 * Main Entego N11 Instance.
	 *
	 * Ensures only one instance of WooCommerce is loaded or can be loaded.
	 *
	 * @since 2.1
	 * @static
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	/**
	 * Bu eklenti için gerekli bağımlılıkları yükleyin.
	 *
	 * Eklentiyi oluşturan aşağıdaki dosyaları ekleyin:
	 *
	 * - Entego_N11_Loader. Eklentinin kancalarını düzenler.
	 * - Entego_N11_Admin. Yönetici alanı için tüm kancaları tanımlar.
	 *
	 * Kancaları kaydetmek için kullanılacak bir yükleyici örneği oluşturun
	 * WordPress ile.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * Projenin eylemlerini ve filtrelerini düzenlemekten sorumlu sınıf
		 * çekirdek eklentisi.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-entego-n11-loader.php';

		/**
		 * Yönetici alanında gerçekleşen tüm eylemleri tanımlamaktan sorumlu sınıf.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-entego-n11-admin.php';

		/**
		 * Yönetici alanı EKlenti kullanma kılavuzu
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/partials/class-entego-n11-help.php';

		/**
		 * Entego Bağlantı Class Çağırma
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-entego-n11-baglanti.php';


		$this->loader = new Entego_N11_Loader();

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {

		$plugin_admin = new Entego_N11_Admin( $this->get_entego_n11(), $this->get_version() );

		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );

	}

	/**
	 * WordPress ile tüm kancaları çalıştırmak için yükleyiciyi çalıştırın.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * İçeriğinde benzersiz olarak tanımlamak için kullanılan eklentinin adı
	 * WordPress ve uluslararasılaştırma işlevselliğini tanımlamak.
	 *
	 * @since     1.0.0
	 * @return    string    Eklentinin adı.
	 */
	public function get_entego_n11() {
		return $this->entego_n11;
	}

	/**
	 * Kancaları eklenti ile düzenleyen sınıfa başvuru.
	 *
	 * @since     1.0.0
	 * @return    Entego_N11_Loader    Eklentinin kancalarını düzenler.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Eklentinin sürüm numarasını alın.
	 *
	 * @since     1.0.0
	 * @return    string    Eklentinin sürüm numarası.
	 */
	public function get_version() {
		return $this->version;
	}

	/**
	 * Eklenti Menüsünü Oluşturma
	 *
	 * @since     1.0.0
	 * @return    string    Eklentinin sürüm numarası.
	 */
	public function menu_ekle() {
		add_menu_page(
			esc_html('Entego E-Ticaret Eklentisi','entego-n11'),
			esc_html('Entego','entego-n11'),
			'manage_options',
			'entego_n11_ayarlar',
			'entego_n11_ayarlar',
			'dashicons-entego',
			'80'
		);
		add_submenu_page(
			'entego_n11_ayarlar',
			esc_html('Entego WooCommerce N11 Entegrasyonu Eklentisi','entego-n11'),
			esc_html('N11 Yayındaki Tüm Ürünler','entego-n11'),
			'manage_options',
			get_admin_url().'edit.php?post_type=product&n11_filtresi=true'
		);
		add_submenu_page(
			'entego_n11_ayarlar',
			esc_html('Siparişler | Entego WooCommerce N11 Entegrasyonu Eklentisi','entego-n11'),
			esc_html('N11 Siparişler','entego-n11'),
			'manage_options',
			'entego_n11_siparisler',
			'entego_siparisler_n11'
		);
		add_submenu_page(
			'entego_n11_ayarlar',
			esc_html('Kategorileri Eşleştir','entego-n11'),
			esc_html('N11 Kategoriler','entego-n11'),
			'manage_options',
			'entego_n11_kategoriler',
			'entego_n11_kategoriler'
		);
		add_submenu_page(
			'entego_n11_ayarlar',
			esc_html('Ürün Gönderme Sonuçları - Entego WooCommerce N11 Entegrasyonu Eklentisi','entego-n11'),
			esc_html('N11 Ürün Gönderme Sonuçları','entego-n11'),
			'manage_options',
			'entego_n11_sonuclar',
			'entego_n11_sonuclar'
		);
		add_submenu_page(
			'entego_n11_ayarlar',
			esc_html('Ayarlar Düzenle - Entego WooCommerce N11 Entegrasyonu Eklentisi','entego-n11'),
			esc_html('Ayarlar','entego-n11'),
			'manage_options',
			'entego_n11_ayarlar',
			'entego_n11_ayarlar'
		);
		$page = add_submenu_page(
			'entego_n11_ayarlar',
			esc_html('Entego N11 Eklentisi Kullanma Talimatları - Entego WooCommerce N11 Entegrasyonu Eklentisi','entego-n11'),
			esc_html('N11 Eklentisi Kullanım Kılavuzu','entego-n11'),
			'manage_options',
			'entego_n11_help',
			'entego_n11_kilavuz'
		);
		add_submenu_page(
			'entego_n11_ayarlar',
			esc_html('Entego Destek Talebi Gönder - Entego WooCommerce N11 Entegrasyonu Eklentisi','entego-n11'),
			esc_html('Destek Talebi Gönder','entego-n11'),
			'manage_options',
			'entego_n11_destek',
			'entego_n11_destek'
		);

		function entego_siparisler_n11(){
			$admin = new Entego_N11_Admin('entego_n11',ENTEGO_N11_VERSION);
			$admin->siparisler_page();
		}
		function entego_n11_kategoriler(){
			$admin = new Entego_N11_Admin('entego_n11',ENTEGO_N11_VERSION);
			$admin->kategoriler();
		}

		function entego_n11_sonuclar(){
			$admin = new Entego_N11_Admin('entego_n11',ENTEGO_N11_VERSION);
			$admin->urunSonuclar();
		}

		function entego_n11_ayarlar(){
			$admin = new Entego_N11_Admin('entego_n11',ENTEGO_N11_VERSION);
			$admin->ayarlar();
		}

		function entego_n11_kilavuz(){
			$help = new Entego_N11_Help('entego_n11',ENTEGO_N11_VERSION);
			$help->get_view();
		}

		function entego_n11_destek(){
			$admin = new Entego_N11_Admin('entego_n11',ENTEGO_N11_VERSION);
			$admin->destek_sayfasi();
		}

    	add_action( "admin_print_styles-{$page}", array($this,'help_sayfasi_include'));
	}

	public function includes(){
		
		if ( !empty( $_GET['page'] ) ) {
			switch ( sanitize_text_field($_GET['page']) ) {
				case 'entego-n11-kurulum':
					include_once dirname( __FILE__ ) . "/../admin/class-entego-n11-admin-kurulum-wizard.php";
					break;
			}
		}
	}

	/**
	 * Get the plugin url.
	 *
	 * @return string
	 */
	public function plugin_url() {
		return untrailingslashit( plugins_url( '/', ENTEGO_N11_PLUGIN_FILE ) );
	}

	/**
	 * İlk Kurulum Anahtarların kontrolü
	 * 
	 */
	public function apiSifrelerKontrol($api,$secret){
		$response = Entego_N11_Baglanti::HTTPPost("yeniKayit", array(
			'api_key' => $api,
			'api_secret_key' => $secret,
			'alan_adi'	=> get_site_url(),
		));
		$response = json_decode($response,true);
		if($response->sonuc == false){	
			update_option('entego_n11_aktif',false);
			return false;
		}elseif($getSablon->result->status == 'success') {
			update_option('entego_n11_aktif',true);
			update_option('entego_n11_key',$response->entego_api);
			return true;
		}
	}

	public function setupComplete(){
		update_option('entego_n11_setup_complete','yes');
		$opt_name = "entego_n11_wizard_bitirme_notu";
		delete_option( $opt_name );
	}

	public function help_sayfasi_include(){
		wp_enqueue_style( $this->entego_n11.'_admin_help', plugin_dir_url( __FILE__ ) . '../admin/css/entego-n11-admin-help.css', array(), $this->version);
		wp_enqueue_script( $this->entego_n11.'_admin_help', plugin_dir_url( __FILE__ ) . '../admin/js/entego-n11-admin-help.js', array(), $this->version, false );
	}
}